bayespy.inference.vmp.nodes.expfamily.ExponentialFamily.lower_bound_contribution
================================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.expfamily

.. automethod:: ExponentialFamily.lower_bound_contribution